let siteData = {};
let activeTabs = {};

// Load existing site data on installation
chrome.runtime.onInstalled.addListener(() => {
  chrome.storage.local.get(null, (result) => {
    siteData = result || {};
  });
});

// Periodically update the time spent on each site
setInterval(() => {
  chrome.tabs.query({}, (tabs) => {
    const now = Date.now();
    tabs.forEach(tab => {
      const site = getDomainFromUrl(tab.url);

      if (!activeTabs[tab.id]) {
        activeTabs[tab.id] = { site, startTime: now, timeSpentToday: 0 };
      } else {
        const timeSpent = now - activeTabs[tab.id].startTime;
        activeTabs[tab.id].timeSpentToday += timeSpent;

        chrome.storage.local.get([site], (result) => {
          const currentTime = result[site] || 0;
          chrome.storage.local.set({ [site]: currentTime + timeSpent });
        });

        activeTabs[tab.id].startTime = now;
      }
    });
  });
}, 10000);

// Clean up when tabs are removed
chrome.tabs.onRemoved.addListener(tabId => {
  delete activeTabs[tabId];
});

// Handle messages for data retrieval and clearing
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
  if (message.type === "getData") {
    chrome.storage.local.get(null, (result) => {
      sendResponse({ allTimeData: result, currentTabs: activeTabs });
    });
    return true; // Indicate asynchronous response
  } else if (message.type === "clearData") {
    chrome.storage.local.clear(() => {
      activeTabs = {};
      sendResponse("Data cleared");
    });
    return true; // Indicate asynchronous response
  }
});

// Extract the main domain from a URL
function getDomainFromUrl(url) {
  let domain = (new URL(url)).hostname;
  const domainParts = domain.split('.').slice(-2); // Get the last two parts of the domain
  return domainParts.join('.');
}
