document.addEventListener('DOMContentLoaded', () => {
  updatePopupData(); // Initial load
  setInterval(updatePopupData, 1000); // Update every second

  document.getElementById('downloadToday').addEventListener('click', () => {
    downloadCSV("today");
  });

  document.getElementById('downloadWeek').addEventListener('click', () => {
    downloadCSV("week");
  });

  document.getElementById('downloadAllTime').addEventListener('click', () => {
    downloadCSV("all");
  });
});

// Update popup data display
function updatePopupData() {
  chrome.runtime.sendMessage({ type: "getData" }, (response) => {
    if (chrome.runtime.lastError) {
      console.error(chrome.runtime.lastError.message);
      return;
    }

    const tabList = document.getElementById('tabList');
    const siteList = document.getElementById('siteList');

    tabList.innerHTML = "";
    siteList.innerHTML = "";

    if (!response.currentTabs || Object.keys(response.currentTabs).length === 0) {
      tabList.innerHTML = "<p>No active tabs tracking data.</p>";
    } else {
      for (let tabId in response.currentTabs) {
        const site = response.currentTabs[tabId].site;
        const timeSpentToday = formatTime(response.currentTabs[tabId].timeSpentToday);
        tabList.innerHTML += `<p>${site}: ${timeSpentToday}</p>`;
      }
    }

    if (!response.allTimeData || Object.keys(response.allTimeData).length === 0) {
      siteList.innerHTML = "<p>No data available.</p>";
    } else {
      for (let site in response.allTimeData) {
        const timeSpent = formatTime(response.allTimeData[site], true);
        siteList.innerHTML += `<p>${site}: ${timeSpent}</p>`;
      }
    }
  });
}

// Download CSV with usage data
function downloadCSV(period) {
  chrome.runtime.sendMessage({ type: "getData" }, (response) => {
    if (chrome.runtime.lastError) {
      console.error(chrome.runtime.lastError.message);
      return;
    }

    let csvContent = "data:text/csv;charset=utf-8,";
    csvContent += "Site,Time Spent (DD:HH:MM:SS)\n";

    for (let site in response.allTimeData) {
      const timeSpent = formatTime(response.allTimeData[site], true);
      csvContent += `${site},${timeSpent}\n`;
    }

    const encodedUri = encodeURI(csvContent);
    const link = document.createElement("a");
    link.setAttribute("href", encodedUri);
    link.setAttribute("download", `${period}_usage.csv`);
    document.body.appendChild(link);

    link.click();
    document.body.removeChild(link); // Clean up after download
  });
}

// Format time in human-readable format
function formatTime(ms, includeDays = false) {
  let totalSeconds = Math.floor(ms / 1000);
  let days = Math.floor(totalSeconds / 86400);
  totalSeconds %= 86400;
  let hours = Math.floor(totalSeconds / 3600);
  totalSeconds %= 3600;
  let minutes = Math.floor(totalSeconds / 60);
  let seconds = totalSeconds % 60;

  if (includeDays) {
    return `${days}:${String(hours).padStart(2, '0')}:${String(minutes).padStart(2, '0')}:${String(seconds).padStart(2, '0')}`;
  } else {
    return `${String(hours).padStart(2, '0')}:${String(minutes).padStart(2, '0')}:${String(seconds).padStart(2, '0')}`;
  }
}
